/***************************************************************************
                          analogoutput.cpp  -  description
                             -------------------
    begin                : Sun Jul 16 2000
    copyright            : (C) 2000 by Joris Struyve
    email                : j.struyve@pandora.be
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

/* CVS information :
 *
 * $Id: analogoutput.cpp,v 1.8 2001/03/02 21:47:39 js Exp $
 *
 */

#include "k8ktest.h"

AnalogOutput::AnalogOutput(int min,int max, int linestep,int pagestep,int value,int io,
						   QString type,QString label,QWidget *parent,char *name)
	:QFrame(parent,name)
{
	this->setFrameStyle(QFrame::Box|QFrame::Raised);
	val = new QScrollBar(min,max,linestep,pagestep,value, Qt::Vertical, this, "scroll");
	valuelabel = new QLabel(this,"val");
	valuelabel->setAlignment(Qt::AlignHCenter);
	valuelabel->setText(tr("%1").arg(value));
	
	cardlabel = new QLabel(this,"card");
	cardlabel->setAlignment(Qt::AlignHCenter);
	cardlabel->setText(label);
	
	/* set the io_channel */
	this->io_channel = io;
	
	/* set the type */
	this->type = type;
	
	/* write initial value to the K8000 card */
	if (io_channel==9)
		OutputDAchannel(io_channel-8,value);
	else
		OutputDACchannel(io_channel,value);
	
	connect( val, SIGNAL(valueChanged(int) ), SLOT(ChangeValue(int)) );
}

AnalogOutput::~AnalogOutput()
{}

void AnalogOutput::SetValue(int value)
{
	/* write requested value to the K8000 card */
	if (this->type=="DA")
		OutputDAchannel(io_channel,value);
	else
		OutputDACchannel(io_channel,value);

	/* change the value label */
	valuelabel->setText(tr("%1").arg(value));
	
	/* change the srollbar */
	val->setValue((value-val->maxValue())*-1);
	
	/* emit the change signal */
	emit this->ValueChanged(value);
}

void AnalogOutput::ChangeValue(int value)
{
	value = (value-val->maxValue())*-1;
	/* write new value (by clicking on the scrollbar) the k8000 card */
	if (this->type=="DA")
		OutputDAchannel(io_channel,value);
	else
		OutputDACchannel(io_channel,value);
	/* update the label with the new value */
	valuelabel->setText(tr("%1").arg(value));
	/* emit the change signal */
	emit this->ValueChanged(value);
}

void AnalogOutput::Refresh()
{
	int i;
	
	i = (val->value()-val->maxValue())*-1;
	Debug("DA %d = %d",io_channel,i);
	/* write the current value to the K8000 card */
	if (this->type=="DA")
		OutputDAchannel(io_channel,i);
	else
		OutputDACchannel(io_channel,i);
}

int AnalogOutput::GetValue()
{ return (val->value()-val->maxValue())*-1; }

void AnalogOutput::SetGeometry(int x,int y,int w,int h,int s)
{
	int borderspace = 3;
	int interspace = 5;
	int texth = 13;
	
	this->setGeometry(x,y,w,h);

	valuelabel->setGeometry(borderspace,h-borderspace-texth,w-2*borderspace,texth);
	cardlabel->setGeometry(borderspace,borderspace,w-2*borderspace,texth);
	val->setGeometry((w/2)-(s/2),texth+interspace+borderspace,s,
					h-(2*texth)-(2*borderspace)-(2*interspace));
	
}
